@@ -3,7 +3,6 @@ from typing import Callable, Dict, Tuple
 
 from streamlit import session_state as _state
 
-# import streamlit.components.v1 as components
 from streamlit.components.v1 import components as _components
 
 from pollination_streamlit.interactors import ApiClient
@@ -471,6 +470,7 @@ def auth_user(key='foo', api_client: ApiClient = None):
 def select_account(
     key='foo',
     api_client: ApiClient = None, *,
+    default_account_username: str = None,
     on_change:  Callable = None,
     args: Tuple = None,
     kwargs: Dict = None,
@@ -491,6 +491,8 @@ def select_account(
         ...
         api_client = get_api_client
         ```
+    default_account_username: str
+        default account name, component will select this account as a default state
     on_change: Callable or None
         An optional on_change function that will be called when hbjson input
         is changed.
@@ -542,6 +544,7 @@ def select_account(
     select_account = _select_account(
       component='select_account',
       key=key,
+      default_account_username=default_account_username,
       access_token=client["_jwt_token"],
       api_key=client["_api_token"],
       base_path=client["_host"]
@@ -620,7 +623,8 @@ def select_cloud_artifact(
 def select_project(
     key='foo', 
     api_client: ApiClient = None, *,
-    project_owner=None,
+    project_owner: str = None,
+    default_project_id: str = None,
     on_change:  Callable = None,
     args: Tuple = None,
     kwargs: Dict = None,
@@ -643,6 +647,8 @@ def select_project(
         ```
     project_owner: str or None
         username of project owner
+    default_project_id: str or None
+        default project id
     on_change: Callable or None
         An optional on_change function that will be called when hbjson input
         is changed.
@@ -714,6 +720,7 @@ def select_project(
       component='select_project',
       key=key,
       project_owner=project_owner,
+      default_project_id=default_project_id,
       access_token=client["_jwt_token"],
       api_key=client["_api_token"],
       base_path=client["_host"]
@@ -724,8 +731,9 @@ def select_project(
 def select_recipe(
     key='foo', 
     api_client: ApiClient = None, *, 
-    project_name=None, 
-    project_owner=None,
+    project_name: str = None, 
+    project_owner: str = None,
+    default_recipe: Dict = None,
     on_change:  Callable = None,
     args: Tuple = None,
     kwargs: Dict = None,
@@ -750,6 +758,8 @@ def select_recipe(
         project name
     project_owner: str or None
         username of the project owner
+    default_recipe: Dict or None
+        recipe json object that will be passed as input to select_recipe
     on_change: Callable or None
         An optional on_change function that will be called when hbjson input
         is changed.
@@ -780,6 +790,7 @@ def select_recipe(
         key=key,
         project_name=project_name,
         project_owner=project_owner,
+        default_recipe=default_recipe,
         access_token=client["_jwt_token"],
         api_key=client["_api_token"],
         base_path=client["_host"])
@@ -788,8 +799,9 @@ def select_recipe(
 
 def select_study(
     key='foo', api_client: ApiClient = None, *,
-    project_name=None,
-    project_owner=None,
+    project_name: str = None,
+    project_owner: str = None,
+    default_study_id: str = None,
     on_change:  Callable = None,
     args: Tuple = None,
     kwargs: Dict = None,
@@ -814,6 +826,8 @@ def select_study(
         name of project
     project_owner: str or None
         username of project owner
+    default_study_id: str or None
+        default study id
     on_change: Callable or None
         An optional on_change function that will be called when hbjson input
         is changed.
@@ -843,6 +857,7 @@ def select_study(
         key=key,
         project_name=project_name,
         project_owner=project_owner,
+        default_study_id=default_study_id,
         access_token=client["_jwt_token"],
         api_key=client["_api_token"],
         base_path=client["_host"])
@@ -851,9 +866,10 @@ def select_study(
 
 def select_run(
     key='foo', api_client: ApiClient = None, *,
-    project_name=None,
-    project_owner=None,
-    job_id=None,
+    project_name: str = None,
+    project_owner: str = None,
+    job_id: str = None,
+    default_run_id: str = None,
     on_change:  Callable = None,
     args: Tuple = None,
     kwargs: Dict = None
@@ -878,6 +894,8 @@ def select_run(
         username of project owner
     job_id: str or None
         id of study
+    default_run_id: str or None
+        default run id
     on_change: Callable or None
         An optional on_change function that will be called when hbjson input
         is changed.
@@ -909,6 +927,7 @@ def select_run(
         project_name=project_name,
         project_owner=project_owner,
         job_id=job_id,
+        default_run_id=default_run_id,
         access_token=client["_jwt_token"],
         api_key=client["_api_token"],
         base_path=client["_host"])
@@ -917,6 +936,7 @@ def select_run(
 
 def create_study(
     key='foo', api_client: ApiClient = None, *,
+    default_inputs: Dict = None,
     on_change:  Callable = None,
     args: Tuple = None,
     kwargs: Dict = None
@@ -937,6 +957,17 @@ def create_study(
         ...
         api_client = get_api_client
         ```
+    default_inputs: Dict
+        A dictionary with the structure
+        
+        {
+            [input_name: string] : {
+                value: string,
+                hidden: boolean
+            }
+        }
+
+        The hidden field is optional.
     on_change: Callable or None
         An optional on_change function that will be called when hbjson input
         is changed.
@@ -1008,7 +1039,7 @@ def recipe_inputs_form(
             }
         }
 
-        The hidden field will be optional, but hasn't been fully implemented yet.
+        The hidden field is optional.
     recipe: Dict
         Dictionary representing a pollination recipe, use select_recipe
     on_change: Callable or None
